@@ -43,7 +43,7 @@ char	*comdstr();
 extern	struct param *ppfind();		/* search task psets for param */
 
 void
-o_undefined (void)
+o_undefined (memel *argp)
 {
 	cl_error (E_IERR, e_uopcode, 0);
 }
@@ -94,7 +94,7 @@ o_absargset (memel *argp)
 /* <op1> <op2> . <op2 + op1>
  */
 void
-o_add (void)
+o_add (memel *argp)
 {
 	binop (OP_ADD);
 }
@@ -147,7 +147,7 @@ o_addassign (memel *argp)
  * includes stdout as well as stderr.
  */
 void
-o_allappend (void)
+o_allappend (memel *argp)
 {
 	struct	operand o;
 	char	*fname, *mode;
@@ -181,7 +181,7 @@ o_allappend (void)
  * redirect everything, including the stderr channel.
  */
 void
-o_allredir (void)
+o_allredir (memel *argp)
 {
 	struct	operand o;
 	char	*fname, *mode;
@@ -213,7 +213,7 @@ o_allredir (void)
 /* <op1> <op2> . <op1 && op2>
  */
 void
-o_and (void)
+o_and (memel *argp)
 {
 	binexp (OP_AND);
 }
@@ -221,7 +221,7 @@ o_and (void)
 /* <name of file to be appended> .
  */
 void
-o_append (void)
+o_append (memel *argp)
 {
 	struct	operand o;
 	char	*fname, *mode;
@@ -289,7 +289,7 @@ o_call (memel *argp)
 /* <op> . <- op>
  */
 void
-o_chsign (void)
+o_chsign (memel *argp)
 {
 	unop (OP_MINUS);
 }
@@ -298,7 +298,7 @@ o_chsign (void)
  * string concatenation
  */
 void
-o_concat (void)
+o_concat (memel *argp)
 {
 	binop (OP_CONCAT);
 }
@@ -306,13 +306,13 @@ o_concat (void)
 /* <op1> <op2> . <op1 / op2>
  */
 void
-o_div (void)
+o_div (memel *argp)
 {
 	binop (OP_DIV);
 }
 
 void
-o_doend (void)
+o_doend (memel *argp)
 {
 }
 
@@ -379,7 +379,7 @@ o_catassign (memel *argp)
 /* <op1> <op2> . <op1 == op2>
  */
 void
-o_eq (void)
+o_eq (memel *argp)
 {
 	binexp (OP_EQ);
 }
@@ -387,7 +387,7 @@ o_eq (void)
 /* run the newtask. see exec.c.
  */
 void
-o_exec (void)
+o_exec (memel *argp)
 {
 	execnewtask ();
 }
@@ -395,7 +395,7 @@ o_exec (void)
 /* <op1> <op2> . <op1 > op2>
  */
 void
-o_ge (void)
+o_ge (memel *argp)
 {
 	binexp (OP_GE);
 }
@@ -415,7 +415,7 @@ o_dogoto (memel *argp)
 /* <op1> <op2> . <op1 > op2>
  */
 void
-o_gt (void)
+o_gt (memel *argp)
 {
 	binexp (OP_GT);
 }
@@ -617,7 +617,7 @@ o_intrinsic (memel *argp)
 /* <op1> <op2> . <op1 <= op2>
  */
 void
-o_le (void)
+o_le (memel *argp)
 {
 	binexp (OP_LE);
 }
@@ -625,7 +625,7 @@ o_le (void)
 /* <op1> <op2> . <op1 < op2>
  */
 void
-o_lt (void)
+o_lt (memel *argp)
 {
 	binexp (OP_LT);
 }
@@ -633,7 +633,7 @@ o_lt (void)
 /* <op1> <op2> . <op2 * op1>
  */
 void
-o_mul (void)
+o_mul (memel *argp)
 {
 	binop (OP_MUL);
 }
@@ -659,7 +659,7 @@ o_mulassign (memel *argp)
 /* <op1> <op2> . <op1 != op2>
  */
 void
-o_ne (void)
+o_ne (memel *argp)
 {
 	binexp (OP_NE);
 }
@@ -667,7 +667,7 @@ o_ne (void)
 /* <op> . <!op>
  */
 void
-o_not (void)
+o_not (memel *argp)
 {
 	unexp (OP_NOT);
 }
@@ -675,7 +675,7 @@ o_not (void)
 /* <op1> <op2> . <op1 || op2>
  */
 void
-o_or (void)
+o_or (memel *argp)
 {
 	binexp (OP_OR);
 }
@@ -734,7 +734,7 @@ o_posargset (memel *argp)
 /* <op1> <op2> . <op1 ** op2>
  */
 void
-o_dopow (void)
+o_dopow (memel *argp)
 {
 	binop (OP_POW);
 }
@@ -746,7 +746,7 @@ o_dopow (void)
  * be printed.
  */
 void
-o_doprint (void)
+o_doprint (memel *argp)
 {
 	/* This is not used -- print is imp. as a builtin task.
 	struct operand o;
@@ -760,7 +760,7 @@ o_doprint (void)
  * used to print an operand on the stack. not to be confused with doprint.
  */
 void
-o_immed (void)
+o_immed (memel *argp)
 {
 	struct operand o;
 
@@ -791,9 +791,12 @@ o_pushconst (memel *argp)
  * when the parameter is accessed.
  */
 void
-o_pushindex (int *mode)
+o_pushindex (
+  memel	*argp
+)
 {
 	struct operand op;
+        int *mode = (int *) argp;
 
 	 if (cldebug)
 	    printf ("PUSHINDEX: mode=%d loopset=%d\n", *mode, imloopset);
@@ -856,7 +859,7 @@ o_pushparam (memel *argp)
 /* <name of file to be used as stdout> .
  */
 void
-o_redir (void)
+o_redir (memel *argp)
 {
 	struct	operand o;
 	char	*fname, *mode;
@@ -889,7 +892,7 @@ o_redir (void)
 /* <name of file to be used as stdin> .
  */
 void
-o_redirin (void)
+o_redirin (memel *argp)
 {
 	struct	operand o;
 	char	*fname, *mode;
@@ -1026,7 +1029,7 @@ o_rmpipes (memel *argp)
 
 
 void
-o_doreturn (void)
+o_doreturn (memel *argp)
 {
 	eprintf ("return not implemented\n");
 }
@@ -1037,7 +1040,7 @@ o_doreturn (void)
  * input.
  */
 void
-o_doscan (void)
+o_doscan (memel *argp)
 {
 	struct operand o;
 
@@ -1046,7 +1049,7 @@ o_doscan (void)
 }
 
 void
-o_doscanf (void)
+o_doscanf (memel *argp)
 {
 	struct operand o;
 	struct operand o_sv[64];
@@ -1082,7 +1085,7 @@ o_doscanf (void)
  * destination params.
  */
 void
-o_dofscan (void)
+o_dofscan (memel *argp)
 {
 	struct operand o;
 
@@ -1091,7 +1094,7 @@ o_dofscan (void)
 }
 
 void
-o_dofscanf (void)
+o_dofscanf (memel *argp)
 {
 	struct operand o, o_sv[64];
 	char	format[SZ_LINE];
@@ -1139,7 +1142,7 @@ o_dofscanf (void)
 /* <op1> <op2> . <op1 - op2>
  */
 void
-o_sub (void)
+o_sub (memel *argp)
 {
 	binop (OP_SUB);
 }
@@ -1171,8 +1174,11 @@ o_subassign (memel *argp)
  * jump table and goes there.
  */
 void
-o_doswitch (int *jmpdelta)
+o_doswitch (
+  memel *argp
+)
 {
+        int *jmpdelta = (int *) argp;
 	int pdft, icase, jmptable;
 	int value=0;
 	struct operand o;
@@ -1301,7 +1307,7 @@ o_swon (memel *argp)
  * executed to load the language package, since it is the root package.
  */
 void
-o_fixlanguage (void)
+o_fixlanguage (memel *argp)
 {
 	register struct ltask *ltp;
 
