@@ -290,65 +290,65 @@ extern void parse_clmodes(struct param *pp, struct operand *newval);
 extern int abbrev(void);
 extern void poffset(int off);
 /* opcodes.c */
-extern void o_undefined(void);
-extern void o_absargset(memel *argp);
-extern void o_add(void);
-extern void o_addassign(memel *argp);
-extern void o_allappend(void);
-extern void o_allredir(void);
-extern void o_and(void);
-extern void o_append(void);
-extern void o_assign(memel *argp);
-extern void o_biff(memel *argp);
-extern void o_call(memel *argp);
-extern void o_chsign(void);
-extern void o_concat(void);
-extern void o_div(void);
-extern void o_doend(void);
-extern void o_divassign(memel *argp);
-extern void o_catassign(memel *argp);
-extern void o_eq(void);
-extern void o_exec(void);
-extern void o_ge(void);
-extern void o_dogoto(memel *argp);
-extern void o_gt(void);
-extern void o_indirabsset(memel *argp);
-extern void o_indirposset(memel *argp);
-extern void o_indxincr(memel *argp);
-extern void o_inspect(memel *argp);
-extern void o_intrinsic(memel *argp);
-extern void o_le(void);
-extern void o_lt(void);
-extern void o_mul(void);
-extern void o_mulassign(memel *argp);
-extern void o_ne(void);
-extern void o_not(void);
-extern void o_or(void);
-extern void o_osesc(memel *argp);
-extern void o_posargset(memel *argp);
-extern void o_dopow(void);
-extern void o_doprint(void);
-extern void o_immed(void);
-extern void o_pushconst(memel *argp);
-extern void o_pushindex(int *mode);
-extern void o_pushparam(memel *argp);
-extern void o_redir(void);
-extern void o_redirin(void);
-extern void o_gsredir(memel *argp);
-extern void o_doaddpipe(memel *argp);
-extern void o_dogetpipe(memel *argp);
-extern void o_rmpipes(memel *argp);
-extern void o_doreturn(void);
-extern void o_doscan(void);
-extern void o_doscanf(void);
-extern void o_dofscan(void);
-extern void o_dofscanf(void);
-extern void o_sub(void);
-extern void o_subassign(memel *argp);
-extern void o_doswitch(int *jmpdelta);
-extern void o_swoff(memel *argp);
-extern void o_swon(memel *argp);
-extern void o_fixlanguage(void);
+extern void  o_absargset (memel *argp);
+extern void  o_add (memel *argp);
+extern void  o_addassign (memel *argp);
+extern void  o_allappend (memel *argp);
+extern void  o_allredir (memel *argp);
+extern void  o_and (memel *argp);
+extern void  o_append (memel *argp);
+extern void  o_assign (memel *argp);
+extern void  o_biff (memel *argp);
+extern void  o_call (memel *argp);
+extern void  o_chsign (memel *argp);
+extern void  o_concat (memel *argp);
+extern void  o_div (memel *argp);
+extern void  o_doend (memel *argp);
+extern void  o_divassign (memel *argp);
+extern void  o_catassign (memel *argp);
+extern void  o_eq (memel *argp);
+extern void  o_exec (memel *argp);
+extern void  o_ge (memel *argp);
+extern void  o_dogoto (memel *argp);
+extern void  o_gt (memel *argp);
+extern void  o_indirabsset (memel *argp);
+extern void  o_indirposset (memel *argp);
+extern void  o_indxincr (memel *argp);
+extern void  o_inspect (memel *argp);
+extern void  o_intrinsic (memel *argp);
+extern void  o_le (memel *argp);
+extern void  o_lt (memel *argp);
+extern void  o_mul (memel *argp);
+extern void  o_mulassign (memel *argp);
+extern void  o_ne (memel *argp);
+extern void  o_not (memel *argp);
+extern void  o_or (memel *argp);
+extern void  o_osesc (memel *argp);
+extern void  o_posargset (memel *argp);
+extern void  o_dopow (memel *argp);
+extern void  o_doprint (memel *argp);
+extern void  o_immed (memel *argp);
+extern void  o_pushconst (memel *argp);
+extern void  o_pushparam (memel *argp);
+extern void  o_redir (memel *argp);
+extern void  o_redirin (memel *argp);
+extern void  o_gsredir (memel *argp);
+extern void  o_doaddpipe (memel *argp);
+extern void  o_dogetpipe (memel *argp);
+extern void  o_rmpipes (memel *argp);
+extern void  o_doreturn (memel *argp);
+extern void  o_doscan (memel *argp);
+extern void  o_doscanf (memel *argp);
+extern void  o_dofscan (memel *argp);
+extern void  o_dofscanf (memel *argp);
+extern void  o_sub (memel *argp);
+extern void  o_subassign (memel *argp);
+extern void  o_swoff (memel *argp);
+extern void  o_swon (memel *argp);
+extern void  o_undefined (memel *argp);
+extern void  o_fixlanguage (memel *argp);
+extern void  o_doswitch (memel *argp);
+extern void  o_pushindex (memel *argp);
 /* operand.c */
 extern void sprop(register char *outstr, register struct operand *op);
 extern void spparval(char *outstr, struct param *pp);
